import 'dart:convert';
import 'dart:io';

import 'package:test/test.dart';
import 'package:tincan/tincan.dart' show Activity, Statement;

void main() {
  test("should import statement result", () {
    final boundary = '4d6a340e6ff64b27814b9b7095ebd26e';
    final result = Statement.fromMixedMultipart(
        boundary, body.replaceAll('\n', '\r\n').codeUnits);
    expect(result, isNotNull);
    //expect(result.length, 1);
    expect(result[0].id, 'b1a21cd9-d1ed-4ded-87cb-fa9f40bb272b');
  });

  test("should import single statement result", () {
    final boundary = '1416c651f2f54d0e9d178eb165492a0c';
    final result =
        Statement.fromMixedMultipart(boundary, body2.replaceAll('\n', '\r\n'));
    expect(result, isNotNull);
    expect(result[0].id, '7b47a074-1277-45c5-97be-a3c9c14e706d');
    expect(result[0].attachments[0].content.length, 'hello world'.length);
  });

  test("should import binary image result", () {
    final boundary = '92d88485da5d4d32bf29127824b3c836';
    final payload = File('test/payload.data').readAsBytesSync();
    final result = Statement.fromMixedMultipart(boundary, payload);
    expect(result, isNotNull);
    expect(result[0].id, 'db6adf7c-09a9-4854-a2b9-bbf087f1371b');
    expect(result[0].attachments[0].content.length, 50836);
  });

  test("should read content with badge", () {
    final statement = Statement.fromJson(json.decode(_bodyWithBadge));

    expect(statement, isNotNull);
    expect(statement.actor, isNotNull);
    expect(statement.result, isNotNull);
    expect(statement.object, isNotNull);
    expect(statement.verb, isNotNull);
    expect(statement.context, isNotNull);
    expect((statement.object as Activity).definition, isNotNull);
    expect((statement.object as Activity).definition.extensions, isNotNull);
  });
}

final body = '''
--4d6a340e6ff64b27814b9b7095ebd26e
Content-Length:39315
Content-Type:application/json; charset=UTF-8

{"statements":[{"id":"b1a21cd9-d1ed-4ded-87cb-fa9f40bb272b","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T01:20:26.934Z","stored":"2019-02-08T01:20:26.934Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"090880de-0e69-4989-ae0c-0492c89320e5","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T01:17:56.780Z","stored":"2019-02-08T01:17:56.780Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"5c905738-6280-4dda-ac12-86816c8f38a8","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T01:17:21.558Z","stored":"2019-02-08T01:17:21.558Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"7ba7cb90-738c-4afa-b6d0-b63bad27d5db","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T01:16:09.772Z","stored":"2019-02-08T01:16:09.772Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"7f4a239c-e671-44a1-a028-591a18597b74","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T00:58:02.010Z","stored":"2019-02-08T00:58:02.010Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"266978c9-e2ed-49ed-af8f-ceba77a1bd26","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T00:57:33.955Z","stored":"2019-02-08T00:57:33.955Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"933a20ba-b6c3-46f0-9487-9250ffa3ec87","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T00:56:51.186Z","stored":"2019-02-08T00:56:51.186Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"c69cab85-6c62-4504-abf6-f84a80628d86","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T00:53:23.038Z","stored":"2019-02-08T00:53:23.039Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"af4c8f74-b9e5-4128-a1f2-b96aea9cb434","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T00:53:23.038Z","stored":"2019-02-08T00:53:23.038Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"b29aff40-84cb-4085-9f72-b0a0186279fb","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T00:53:03.686Z","stored":"2019-02-08T00:53:03.687Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"c004d35e-a7cf-47b8-b199-8bb25a73f239","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T00:53:03.686Z","stored":"2019-02-08T00:53:03.686Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"e7400fed-84b6-48c7-a1d0-80806023bb4b","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T00:51:33.354Z","stored":"2019-02-08T00:51:33.355Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"2e22b54a-4824-4180-aba9-2f70cb2fa202","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T00:51:33.354Z","stored":"2019-02-08T00:51:33.354Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"dc74962c-3019-4f1c-8586-878e1b04410f","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T00:47:52.957Z","stored":"2019-02-08T00:47:52.957Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"},{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display 2"},"description":{"en-US":"Test Description 2"},"contentType":"text/plain","length":13,"sha2":"ed12932f3ef94c0792fbc55263968006e867e522cf9faa88274340a2671d4441"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"c22eaded-e8a9-41da-9eb9-638774a488ba","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T00:47:38.249Z","stored":"2019-02-08T00:47:38.249Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"},{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display 2"},"description":{"en-US":"Test Description 2"},"contentType":"text/plain","length":13,"sha2":"ed12932f3ef94c0792fbc55263968006e867e522cf9faa88274340a2671d4441"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"2cfcf570-b946-408f-a8d9-e926df2317eb","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T00:45:43.924Z","stored":"2019-02-08T00:45:43.924Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"ac970158-2aba-4209-b5d8-942d1b449dff","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T00:45:11.802Z","stored":"2019-02-08T00:45:11.802Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"370607b0-db1c-45e9-9393-f4d65f6469f3","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T00:44:01.658Z","stored":"2019-02-08T00:44:01.658Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"fcc7c756-743e-4f6e-8d91-ea7bb0cbcb22","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T00:43:35.748Z","stored":"2019-02-08T00:43:35.748Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"3de0f6ab-1b9d-4f62-97fc-375a71580205","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-08T00:37:53.580Z","stored":"2019-02-08T00:37:53.580Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"7675b013-4269-40bd-ac89-d5f530bca507","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-07T22:03:06.349Z","stored":"2019-02-07T22:03:06.349Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"b1797d17-d358-46aa-92ae-ddc1b9641bef","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-07T21:58:57.178Z","stored":"2019-02-07T21:58:57.178Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"5ec352c4-6874-4062-89d1-04d4ca9559c7","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-07T21:58:08.947Z","stored":"2019-02-07T21:58:08.947Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"05d9d4d6-4e04-4acf-a171-e46825c0a400","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-07T21:57:35.669Z","stored":"2019-02-07T21:57:35.669Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"78d715c4-53cd-47ae-b5d0-56f763bae3a8","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-07T21:56:32.745Z","stored":"2019-02-07T21:56:32.745Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"037410a4-69a1-4892-bb32-59f49451e0b0","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-07T21:54:50.614Z","stored":"2019-02-07T21:54:50.614Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"a57136c6-33ae-44bc-8dfb-e2efc3bf7d3b","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-07T21:54:20.799Z","stored":"2019-02-07T21:54:20.799Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"a3f1872c-36bd-4eaf-9a4c-03470e71f9cc","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-07T21:53:55.543Z","stored":"2019-02-07T21:53:55.543Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"9438e3c0-dac1-46d9-9b7b-1c13f3237271","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-07T21:52:09.556Z","stored":"2019-02-07T21:52:09.556Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"7d8201bf-9cff-4a80-8906-e2639deb0518","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-07T21:50:40.079Z","stored":"2019-02-07T21:50:40.079Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"44e37259-e650-4359-9fd6-ce2f09b27667","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-07T21:49:08.881Z","stored":"2019-02-07T21:49:08.881Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"059b16c3-2bed-4532-ab86-2f53500d8cbb","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-07T21:48:30.163Z","stored":"2019-02-07T21:48:30.163Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"38769243-f5b3-472c-83ae-d8cf8ce76b82","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-07T21:40:45.153Z","stored":"2019-02-07T21:40:45.153Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"267576b7-668e-475c-96a4-be9134167efe","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-05T00:42:49.280Z","stored":"2019-02-05T00:42:49.280Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test"},"objectType":"Activity"}},{"id":"b13166dd-fac0-483f-89a4-b9646ba7e124","actor":{"mbox":"mailto:tincanjs-test-tincan+1549229795912@tincanapi.com","objectType":"Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en":"experienced"}},"timestamp":"2019-02-03T21:36:38.597Z","stored":"2019-02-03T21:36:38.789Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","object":{"id":"http://tincanapi.com/TinCanJS/Test/TinCan.LRS-browser","objectType":"Activity"}},{"id":"2086d0d9-486e-40a9-9289-17841dc5fba2","actor":{"mbox":"mailto:tincanjs-test-tincan+1549229795912@tincanapi.com","objectType":"Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"und":"experienced"}},"timestamp":"2019-02-03T21:36:37.797Z","stored":"2019-02-03T21:36:38.017Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","object":{"id":"http://tincanapi.com/TinCanJS/Test/TinCan.LRS-browser","objectType":"Activity"}},{"id":"84680a41-01a3-42d1-af70-42939a11b76d","actor":{"mbox":"mailto:tincanjs-test-tincan+1549229795912@tincanapi.com","objectType":"Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"und":"experienced"}},"timestamp":"2019-02-03T21:36:36.975Z","stored":"2019-02-03T21:36:37.114Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","object":{"id":"http://tincanapi.com/TinCanJS/Test/TinCan.LRS-browser","objectType":"Activity"}},{"id":"9f388843-66b8-40a4-babc-7240de2f57d9","actor":{"mbox":"mailto:tincanjs-test-tincan+1549229795912@tincanapi.com","objectType":"Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"und":"experienced"}},"timestamp":"2019-02-03T21:36:35.963Z","stored":"2019-02-03T21:36:36.220Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","object":{"id":"http://tincanapi.com/TinCanJS/Test/TinCan.LRS-browser","objectType":"Activity"}},{"id":"d2d6f033-1495-4bc4-a8f1-49d01a290fa7","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"context":{"registration":"b961e2fd-e513-4fb0-b0c3-936f3962f6fc","contextActivities":{"parent":[{"id":"http://tincanapi.com/TinCanJava/Test/","definition":{"name":{"en-US":"TinCanJavava Tests"},"description":{"en-US":"Unit test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test-suite/","moreInfo":"http://rusticisoftware.github.io/TinCanJava/"},"objectType":"Activity"}]},"statement":{"id":"191ba4bd-7a06-4563-b915-89c1f41e4f78","objectType":"StatementRef"}},"timestamp":"2019-02-03T21:11:44.334Z","stored":"2019-02-03T21:11:44.335Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}},{"id":"428fcb5c-e16d-475e-b308-c1e618b72b09","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-03T21:11:44.334Z","stored":"2019-02-03T21:11:44.334Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","object":{"id":"http://tincanapi.com/TinCanJava/Test/","definition":{"name":{"en-US":"TinCanJavava Tests"},"description":{"en-US":"Unit test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test-suite/","moreInfo":"http://rusticisoftware.github.io/TinCanJava/"},"objectType":"Activity"}}],"more":""}
--4d6a340e6ff64b27814b9b7095ebd26e
X-Experience-API-Hash:b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9
Content-Transfer-Encoding:binary
Content-Length:11
Content-Type:application/octet-stream

hello world
--4d6a340e6ff64b27814b9b7095ebd26e
X-Experience-API-Hash:ed12932f3ef94c0792fbc55263968006e867e522cf9faa88274340a2671d4441
Content-Transfer-Encoding:binary
Content-Length:13
Content-Type:text/plain

hello world 2
--4d6a340e6ff64b27814b9b7095ebd26e--
''';

final body2 = '''
--1416c651f2f54d0e9d178eb165492a0c
Content-Length:1039
Content-Type:application/json; charset=UTF-8

{"id":"7b47a074-1277-45c5-97be-a3c9c14e706d","actor":{"mbox":"mailto:tincanjava@tincanapi.com","objectType":"Agent","name":"Test Agent"},"verb":{"id":"http://adlnet.gov/expapi/verbs/experienced","display":{"en-US":"experienced"}},"timestamp":"2019-02-09T20:55:22.911Z","stored":"2019-02-09T20:55:22.911Z","authority":{"account":{"homePage":"http://cloud.scorm.com","name":"9L2Q71kgCTHPMGgqG-8"},"objectType":"Agent","name":"Unnamed Account"},"version":"1.0.0","attachments":[{"usageType":"http://id.tincanapi.com/attachment/supporting_media/","display":{"en-US":"Test Display"},"description":{"en-US":"Test Description"},"contentType":"application/octet-stream","length":11,"sha2":"b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9"}],"object":{"id":"http://tincanapi.com/TinCanJava/Test/Unit/0/","definition":{"name":{"en-US":"TinCanJava Tests: Unit 0"},"description":{"en-US":"Unit test 0 in the test suite for the Tin Can Java library."},"type":"http://id.tincanapi.com/activitytype/unit-test/"},"objectType":"Activity"}}
--1416c651f2f54d0e9d178eb165492a0c
X-Experience-API-Hash:b94d27b9934d3e08a52e52d7da7dabfac484efe37a5380ee9088f7ace2efcde9
Content-Transfer-Encoding:binary
Content-Length:11
Content-Type:application/octet-stream

hello world
--1416c651f2f54d0e9d178eb165492a0c--
''';

final _bodyWithBadge = '''
{
  "actor": {
    "name": "Example Earner",
    "mbox": "mailto:earner@example.com"
  },
  "verb": {
    "id": "http://specification.openbadges.org/xapi/verbs/earned",
    "display": {
      "en-US": "earned"
    }
  },
  "result": {
    "extensions": {
      "http://specification.openbadges.org/xapi/extensions/badgeassertion": {
        "@id": "http://www.example.com/assertion/1"
      }
    }
  },
  "context": {
    "contextActivities": {
      "category": [{
        "id": "http://specification.openbadges.org/xapi/recipe/base/0_0_2",
        "definition": {
          "type": "http://id.tincanapi.com/activitytype/recipe"
        },
        "objectType": "Activity"
      }]
    }
  },
  "attachments": [{
    "usageType": "http://specification.openbadges.org/xapi/attachment/badge",
    "display": {
      "en-US": "Name of the badge"
    },
    "contentType": "image/png",
    "length": 48826,
    "sha2": "42a33cb2af34603730577c2e5ddd78858feb34860c4e5bf0f473fa7456d3994a"
  }],
  "object": {
    "id": "http://www.example.com/badgeclass/1",
    "definition": {
      "extensions": {
        "http://specification.openbadges.org/xapi/extensions/badgeclass": {
          "@id": "http://www.example.com/badgeclass/1",
          "image": "http://www.example.com/badgeimage/1.png",
          "criteria": "http://www.example.com/criteria/1",
          "issuer": "http://www.example.com/issuer/1"
        }
      },
      "name": {
        "en-US": "Name of the badge"
      },
      "description": {
        "en-US": "Description of the badge."
      },
      "type": "http://activitystrea.ms/schema/1.0/badge"
    },
    "objectType": "Activity"
  }
}
''';
